//! Types that are tied to objects, but aren't objects themselves

pub mod curve;
pub mod surface;
